import React from 'react';
import {connect} from 'react-redux';
import CVESeverityReport from './cve-severity-report';
import Loader from '../loader';

const loaderStyle = {
  top: '50%',
};

class CVESeverityReportContainer extends React.PureComponent {
  render() {
    const {reportView, ...rest} = this.props;
    const initiatedByPollable = reportView.get('initiatedByPollable');
    const loading = reportView.get('loading') && !initiatedByPollable;
    const data = reportView.get('labelled_report') || [];
    const emptyData = data.length === 0 && !loading;
    return (
      <div>
        {loading && data.length === 0
          && (
          <Loader
            small
            style={loaderStyle}
          />
          )
        }
        {emptyData
          && (
          <div className="absolute-center">
            No Data Available
          </div>
          )}
        <CVESeverityReport
          data={data}
          {...rest}
        />
      </div>
    );
  }
}

const mapStateToProps = state => ({
  reportView: state.getIn(['cve', 'severity_report_view']),
  globalSearchQuery: state.get('globalSearchQuery')
});

export default connect(mapStateToProps)(CVESeverityReportContainer);
