/* eslint-disable react/destructuring-assignment */
import React from 'react';
import {connect} from 'react-redux';
import {
  saveRegistryCredentialAction,
  clearContainerImageRegistryAddFormAction,
  listRegistryCredentialsAction,
  listRegistryImagesAction,
  doNotChangeComponent,
  breadcrumbChange
} from '../../../actions/app-actions';
import CredentialsForm from './credentials-form';
import RegistryCredentialsList from './credentials-list';
import injectModalTrigger from '../../common/generic-modal/modal-trigger-hoc';

// TODO: Rename  to  generic name
class ECRCredentials extends React.PureComponent {
  constructor(props) {
    super(props);
    this.saveRegistryCredentials = this.saveRegistryCredentials.bind(this);
    this.showFormHandler = this.showFormHandler.bind(this);
    this.renderModalContent = this.renderModalContent.bind(this);
    this.getRegistry = this.getRegistry.bind(this);
    this.getImages = this.getImages.bind(this);
    this.changeComponent = this.changeComponent.bind(this);
  }

  componentDidMount() {
    const something = {
      ecr: 'ECR',
      azure_container_registry: 'Azure',
      google_container_registry: 'Google Container Registry',
      docker_hub: 'Docker Hub',
      docker_private_registry: 'Docker (Self Hosted)',
      quay: 'Quay',
      harbor: 'Harbor',
      gitlab: 'Gitlab',
      jfrog_container_registry: 'Jfrog'
    };
    this.props.dispatch(breadcrumbChange([{name: 'Registries', link: '/registry_vulnerability_scan'}, {name: something[this.props.registryType]}]));
  }

  componentDidUpdate() {
    const match = '/registry_vulnerability_scan';
    if (window.location.hash === `#${match.path}`) {
      this.props.dispatch(doNotChangeComponent());
    }
  }

  changeComponent() {
    this.props.dispatch(doNotChangeComponent());
  }

  getRegistry() {
    const {
      listRegistryCredentialsAction: action,
      registryType,
    } = this.props;
    action({
      registryType,
    });
  }

  getImages(registryId) {
    const {
      listRegistryImagesAction: action,
      registryType,
    } = this.props;

    const params = {
      registryId,
      registryType,
    };

    return action(params);
  }

  saveRegistryCredentials(valuesIm) {
    const values = valuesIm.toJS();
    const {
      saveRegistryCredentialAction: action,
      registryType,
    } = this.props;
    const params = {
      ...values,
      registry_type: registryType,
    };
    const promise = action(params);
    promise.then((response = {}) => {
      this.getRegistry();
      const {
        data,
      } = response;
      if (data) {
        // The response from get Images is required
        // to calculate total images which will be
        // shown in credentials table
        this.getImages(data);
      }
    });
    return promise;
  }

  renderModalContent(props) {
    const {
      hideModal,
      registryType,
      formFields,
      instructions = {},
    } = this.props;

    const {
      initialValues = {},
    } = props;

    return (
      <CredentialsForm
        credentialsFieldList={formFields}
        onSubmit={this.saveRegistryCredentials}
        hide={hideModal}
        registryType={registryType}
        initialValues={initialValues}
        instructions={instructions}
      />
    );
  }

  showFormHandler({initialValues = {}, }) {
    const {
      clearContainerImageRegistryAddFormAction: clearAction,
    } = this.props;
    const modalProps = {
      title: 'Save Registry Credentials',
      modalContent: this.renderModalContent,
      modalContentProps: {
        initialValues,
      },
      contentStyles: {
        width: '500px',
      },
      onHide: () => {
        clearAction();
      },
    };
    const {triggerModal} = this.props;
    triggerModal('GENERIC_MODAL', modalProps);
  }

  render() {
    const {
      registryType,
      initialValues = {}
    } = this.props;
    return (
      <div>
        <div className="heading registry-heading">
          <div className="title-bar" style={{marginLeft: 'auto', marginRight: '1rem'}}>
            <div className="add-btn">
              <button
                type="button"
                className="btn-primary add-registry"
                onClick={() => this.showFormHandler({initialValues})}
            >
                + Add Registry
              </button>
            </div>
          </div>
        </div>
        <RegistryCredentialsList
          registryType={registryType}
          triggerEdit={this.showFormHandler}
        />
      </div>
    );
  }
}

export default injectModalTrigger(connect(null, {
  saveRegistryCredentialAction,
  clearContainerImageRegistryAddFormAction,
  listRegistryCredentialsAction,
  listRegistryImagesAction,
})(ECRCredentials));
